Назад до магазину
WorldGuard
Modrinth Plugin

WorldGuard

WorldGuard lets you and players guard areas of land against griefers and undesirables as well as tweak and disable various gameplay features of Minecraft.

Інформація про Minecraft-продукт

Важливе про товар

Сумісність, версії Minecraft, завантажувачі та дані зовнішнього джерела.

Тип

Plugin

Доступ

Безкоштовно

Остання версія

7.0.17

Завантаження

669 873

Завантажувачі / Платформи

bukkit folia paper spigot

Minecraft версії

1.2.4 – 1.2.5 1.3.2 1.4.2 1.4.6 – 1.5.2 1.6.1 – 1.6.4 1.7.2 – 1.7.4 1.7.9 1.8 – 1.8.1 1.9 1.10 1.11 1.12 1.13 1.14 1.15 1.16 1.17 1.18.1 – 1.20.2 1.20.4 1.20.6 – 1.21.1 1.21.3 – 1.21.8 1.21.10 – 1.21.11 26.1 26.1.1 26.1.2 26.2

Категорії

library management utility

Опис

Докладна інформація

<center> <img src="https://raw.githubusercontent.com/EngineHub/WorldGuard/master/worldguard-logo.svg" alt="WorldGuard logo" width="345" height="93" /><br><br> <br> <br> **Protect your server!** <br> WorldGuard lets you and players guard areas of land against griefers and undesirables as well as tweak and disable various gameplay features of Minecraft. <br><br> <iframe width="560" height="315" src="https://www.youtube-nocookie.com/embed/2BaA6ma8L-E" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe> <br> <br> <br> <img src="https://i.imgur.com/boGmtYa.png" alt="Installation"> <br> </center> 🛑 Make sure that you are using the Java version of Minecraft.<br><br> 1. Set up a Bukkit server such as <a href="https://spigotmc.org">Spigot</a> or <a href="https://papermc.io/">Paper</a> (<a href="https://madelinemiller.dev/blog/paper-vs-spigot/">Paper is recommended over Spigot</a>).<br> 2. Download WorldEdit <a href="https://modrinth.com/plugin/worldedit">from the WorldEdit page</a>.<br> 3. Download WorldGuard from this page (see the Files tab above for all versions).<br> 4. Put the WorldEdit and WorldGuard plugin files into your plugins folder.<br><br> Check YouTube for tutorials, or read the official <a href="https://worldguard.enginehub.org/en/latest/">documentation</a>.<br><br> <br> <br> <br> <center><img src="https://i.imgur.com/C0ek15q.png" alt="Discord Server"></center> <br> <a style="font-size: 100%" href="https://discord.gg/enginehub"><img src="https://discordapp.com/api/v6/guilds/80853743897149440/widget.png?style=banner2" alt="" width="320" height="76" /></a><br><br> [Join our Discord server](https://discord.gg/enginehub) if you need help with installing or using WorldGuard. **Make sure to [check the docs](https://worldguard.enginehub.org/en/latest/) first!** <br> <br> <br> <center><img src="https://i.imgur.com/xZAB7cO.png" alt="Highlights"></center> <br> <ul> <li><a href="https://worldguard.enginehub.org/en/latest/regions/">Create zones in your world</a> that only permit mods or certain players from building within</li> <li>Set <a href="https://worldguard.enginehub.org/en/latest/config/">additional game rules</a> on your server (deny wither block damage, falling damage, etc.)</li> <li>Set <a href="https://worldguard.enginehub.org/en/latest/regions/flags/">game rules on specific areas</a> (food regen, health regen, disable PvP, TNT, control mob damage) in your world</li> <li><a href="https://worldguard.enginehub.org/en/latest/blacklist/">Blacklist certain items and blocks</a> so they can't be used</li> <li>Dump useful statistics and information about your server (/wg report -p)</li> <li>CPU profile your server (/wg profile -p)</li> <li>Add <a href="https://worldguard.enginehub.org/en/latest/commands/">useful commands</a> like an immediate "STOP ALL FIRE SPREAD" command.</li> <li>Works, <a href="https://worldguard.enginehub.org/en/latest/regions/scope/#mod-and-plugin-support">more or less</a>, with mods (other Bukkit plugins and FTB mods)</li> <li>Protects against <a href="https://worldguard.enginehub.org/en/latest/regions/scope/">many types of grief</a> (fire spread, tree growth, TNT cannons, piston machines, crop trampling, paintings and item frames, etc.), and certain interactions can also be allowed (door open, lever usage, etc.)</li> <li><a href="https://worldguard.enginehub.org/">Well documented</a>, and one of the oldest Minecraft projects (older than Bukkit!)</li> <li><a href="https://github.com/enginehub/worldguard">Open source</a></li> <li><strong>Enable only features you want! Everything is off by default.</strong> You can just install WorldGuard and configure it later.</li> </ul> <br> <br> <br> <center><img src="https://i.imgur.com/js55Dzh.png" alt="Frequently Asked Questions"></center><br> **Can anyone use it?**<br> Only opped users or users with permissions supplied with a permissions plugin can use WorldGuard.<br><br> **How do you use WorldGuard?**<br> To learn how to use WorldGuard, <a style="font-size: 100%" href="https://worldguard.enginehub.org/en/latest/">read the docs</a>. Check YouTube for tutorials too!<br><br> **I need help!!**<br> You may visit our <a style="font-size: 100%" href="https://worldguard.enginehub.org/en/latest/">documentation</a> or <a style="font-size: 100%" href="https://discord.gg/enginehub">Discord Guild</a>.<br><br> **I have some feature requests...**<br> Visit our <a style="font-size: 100%" href="https://github.com/EngineHub/WorldGuard/issues">issue tracker</a>. However, if you just have a question, please try one of the methods above.<br><br> **Can I edit the source code?**<br> Visit our <a style="font-size: 100%" href="https://github.com/EngineHub/WorldGuard">GitHub repository</a>. WorldGuard is licensed under LGPLv3 and you can compile it with Gradle.<br><br> <br> <br> <br> <center> <a href="https://github.com/sponsors/EngineHub">🎉 Support us on GitHub Sponsors!</a><br><br> <a href="https://billing.apexminecrafthosting.com/aff.php?aff=3108"> Need a host? We recommend Apex Hosting<br> <img alt="Apex Hosting" src="https://enginehub.org/images/apex.svg" width="334" height="91" /> </a> </center>

Розробник

me4502

Профіль і дані отримано з Modrinth

Відкрити на Modrinth

Галерея продукту

Зображення проєкту

Скриншоти та зображення з оригінальної сторінки Modrinth.

Список змін

Версії проєкту

Опубліковані версії та оригінальні файли Modrinth.

7.0.17 Актуальна Release 30.05.2026

WorldGuard 7.0.17 (MC 1.21.11-26.2)

Підтримувані версії Minecraft
1.21.11 26.1 26.1.1 26.1.2 26.2
Завантажувачі / Платформи
bukkit folia paper spigot
Показати зміни
## 7.0.17 * Fix cocoa not being treated as a crop in relevant flags * Fix overlapping game mode flags sometimes not storing the expected previous game mode * Replace PaperLib functionality that doesn't behave as expected on MC 26.1+
7.0.16 Release 24.03.2026

WorldGuard 7.0.16 (MC 1.21.11-26.1.2)

Підтримувані версії Minecraft
1.21.11 26.1 26.1.1 26.1.2
Завантажувачі / Платформи
bukkit folia paper spigot
Показати зміни
## 7.0.16 * Update to 1.21.11. * Added experimental Folia support. * Workaround an issue where some item/block names aren't adequately translated by the client. * Workaround a duplication bug in Paper.
7.0.16-beta-01 Beta 06.01.2026

WorldGuard 7.0.16 Beta 1 (MC 1.21.11)

Підтримувані версії Minecraft
1.21.11
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## 7.0.16 Beta 1 * Update to 1.21.11
7.0.15 Release 06.01.2026

WorldGuard 7.0.15 (MC 1.21.10-1.21.11)

Підтримувані версії Minecraft
1.21.10 1.21.11
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## 7.0.15 * Update a few missed material definitions from the beta ## 7.0.15 Beta 1 * Update to 1.21.10 * Improve region file loading compatibility with NIO Java APIs
7.0.15-beta-01 Beta 01.11.2025

WorldGuard 7.0.15 Beta 1 (MC 1.21.10-1.21.11)

Підтримувані версії Minecraft
1.21.10 1.21.11
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## 7.0.15 Beta 1 * Update to 1.21.10 * Improve region file loading compatibility with NIO Java APIs
7.0.14 Release 12.06.2025

WorldGuard 7.0.14 (MC 1.21.5-1.21.8)

Підтримувані версії Minecraft
1.21.5 1.21.6 1.21.7 1.21.8
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## 7.0.14 * Update to 1.21.5 * Fix hopper minecarts not being able to take items from containers in protected regions. * Fix hopper minecarts not being able to take items from other hopper minecarts in protected regions. * Fix non-members being able to leash boats in protected regions. * Use new knockback event on Paper servers to better handle mace knockback in pvp and some other knockback situations.
7.0.13 Release 16.02.2025

WorldGuard 7.0.13 (MC 1.21.4)

Підтримувані версії Minecraft
1.21.4
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## 7.0.13 * Update to 1.21.4 * Remove max-stack-size bypass in stack command * Fix a falling block metadata leak. (May still be problematic on Spigot, use Paper.) * Fix flame enchant being blocked as entity damage on the arrow itself. * More Paper-specific performance enhancements for hoppers. * Fix block-windcharge-explosions config option not doing anything. * Improvements to fishing rod protection. * More aggressive vehicle protection (vehicle-destroy now needs to be allowed for various non-destructive damage). * Move decorated pot usage from interact to chest-access.
7.0.13-beta-2 Beta 21.12.2024

WorldGuard 7.0.13 beta 2 (MC 1.21.4)

Підтримувані версії Minecraft
1.21.4
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
* Add support for 1.21.4. * Fix block-windcharge-explosions config option.
7.0.13-beta-1 Beta 09.11.2024

WorldGuard 7.0.13 beta 1 (MC 1.21.3)

Підтримувані версії Minecraft
1.21.3
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
* Add support for MC 1.21.3. * Remove max-stack-size bypass in stack command * Fix a falling block metadata leak. (May still be problematic on Spigot, use Paper.) * Fix flame enchant being blocked as entity damage on the arrow itself. * More Paper-specific performance enhancements for hoppers.
7.0.12 Release 13.09.2024

WorldGuard 7.0.12 (for MC 1.21 - 1.21.1)

Підтримувані версії Minecraft
1.21 1.21.1
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
* Fix a change in the default behavior of explosion flag handling.
7.0.11 Release 11.09.2024

WorldGuard 7.0.11 (for MC 1.21-1.21.1)

Підтримувані версії Minecraft
1.21 1.21.1
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
This is the earliest release of WorldGuard on Modrinth. For earlier versions, please see our [CurseForge page](https://dev.bukkit.org/projects/worldguard). * Add support for MC 1.21. * Add wind-charge-burst flag which is checked along with `use` (for the interaction) or `pvp` (for the knockback). * Add breeze-charge-explosion flag for breeze charges (i.e. from the mob, not player wind charges). * Add moisture-change flag and config options. * Fix an error if a player logged in to an unloaded world. * Fix chest boat usage always being counted as ride. * Consider potions thrown by mobs as mob-damage. * Workaround spigot no longer sending block change events when a book is placed on a lectern. * Improve accuracy of target blocks in blacklist/build-perms events. **Known Issues**: Spigot still doesn't throw events in all cases for knockback from both wind charges and maces ("smash attacks"). These are small edge cases but should work immediately in WorldGuard if Spigot does start throwing events for those cases.
7.0.10 Release 10.09.2024

WorldGuard 7.0.10 (MC 1.20.6)

Підтримувані версії Minecraft
1.20.6
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.10 (MC 1.20.6) **This version is compatible with:** - Bukkit implementations for 1.20.6 only ([Paper ](https://papermc.io/)recommended, 1.20.5 probably works but was only out for 3 days so who cares) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.20.5 - Like Minecraft 1.20.6, this requires Java 21 or higher. Java 17 will no longer work. - Add support for MC 1.20.6. - Add some Paper-exclusive optimizations.
7.0.9 Release 10.09.2024

WorldGuard 7.0.9 (MC 1.20 - 1.20.4)

Підтримувані версії Minecraft
1.20 1.20.1 1.20.2 1.20.4
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.9 (MC 1.20 - 1.20.4) **This version is compatible with:** - Bukkit implementations for 1.20(.1, .2, .4) ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.20 - Add support for MC 1.20 - Made entities spawned via the `/summon` command get treated as plugin-spawned entities - Add sniffer egg trample protection options New since last beta: - Fixed an event change that spigot made that broke the copper-fade flag. - Bumped API version to prevent running on 1.19.
7.0.8 Release 10.09.2024

WorldGuard 7.0.8 (MC 1.19-1.19.4)

Підтримувані версії Minecraft
1.19 1.19.1 1.19.2 1.19.3 1.19.4
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.8 (MC 1.19-1.19.4) **This version is compatible with:** - Bukkit implementations for 1.19-1.19.4 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.19 - Add support for MC 1.19 - Add skulk-growth flag and config option - Add copper-fade flag - Add data packs to report output - Add protection for allay inventory slot - Categorize allay item pickups under item-pickup flag - Categorize dragon egg interaction (teleporting) as building - Ignore most NPC-based actions for Player events - Optimize handling of tamed animals where the owner was offline (Paper only) - Optimize additional InventoryHolder accesses (Paper only) - Fix an exception that occurred when plugins created portals with non-player entities - Fix possible error when using Paper's entity origin API - Update bstats and squirrelid libs
7.0.7 Release 10.09.2024

WorldGuard 7.0.7 (MC 1.17.1-1.18.2)

Підтримувані версії Minecraft
1.17 1.18.1 1.18.2
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.7 (MC 1.17.1-1.18.2) **This version is compatible with:** - Bukkit implementations for 1.17.1 - 1.18.2 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.17 - Add rock-growth flag for budding amethyst and pointed dripstone. - Add /rg migrateheights command. See [https://worldguard.enginehub.org/en/latest/regions/commands/#migrate-region-heights](https://worldguard.enginehub.org/en/latest/regions/commands/#migrate-region-heights) - Add regions.set-parent-on-claim config (set to a region id for /rg claim to automatically assign the parent region). - Add `-i search` and `-s` flags to /rg list, -c to /rg teleport. - Fix an error in blacklist logging caused by non-player actions (eg on-dispense) - Treat unknown causes as known if using paper-entity-origin config option. - Improve lightning strike handling from channeling tridents (Paper only). - Ignore an error caused by lingering player references of offline players. - Add red sand to no-physics-sand. - Fix potion splash events being cancelled if no entities were affected.
7.0.6 Release 10.09.2024

WorldGuard 7.0.6 (superceded)

Підтримувані версії Minecraft
1.17 1.18.1
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.6 (superceded) **This version is compatible with:** - Bukkit implementations for 1.17.1+ ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.17 - This version is also compatible with 1.18. - Add support for 1.17 blocks/items, drop support for 1.16. - Add use-dripleaf flag for "toggling" big dripleaf blocks. - Fix support for fully negative-height regions. - Fix crop-growth config option. - Be more rigorous with protecting blocks against dispenser behaviors. - Fix handling of lingering splash potion effects. - Handle other-explosion flag consistently for block-like entities (armor frames etc.) - Allow inheriting values for all flags (previously wasn't used for things like teleport.) - Region commands that defaulted to the region the player was standing in no longer check parents. - Fix child regions being unlinked when redefining a parent region.
7.0.5 Release 10.09.2024

WorldGuard 7.0.5 (MC 1.16.5)

Підтримувані версії Minecraft
1.16
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.5 (MC 1.16.5) **This version is compatible with:** - CraftBukkit/Spigot for 1.16.5 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.16 - Add a use-anvil flag and exclude it from the use flag (since they can break on use.) - Expand crop-related options (crop-growth, etc) to sweet berry bushes, nether wart, and bamboo. - Add a config option ('mobs.block-vehicle-entry') to prevent non-players from entering vehicles. - Add a UUID flag (for developers/API usage). - Add map query methods with fallback flag (for developers/API usage). - Add 'on' and 'off' optional arguments for `/rg toggle-bypass` command. - Add additional timings info for session handlers. - Fix sponge-simulation clearing NBT from blocks. Note that if you are using sponge simulation you should switch to something like CraftBook as the feature will be removed from WorldGuard in a future (major) version. - Fix the '/region' command showing up as unknown client-side to players without bypass perms. - Fix error propagation from third-party flag loading causing WG to error. - Fix a (harmless) exception that occurred when swapping armor slots to the offhand slot. - Fix empty lines being sent on enderpearl/chorus-fruit teleport if the deny messages were empty. - Fix an issue with falling blocks when using max-priority-association. - Fix performance issues with third-party plugins querying protection for offline players. - Fix dispensing shulkers over region boundaries. - Fix iron door interaction being denied as if it were a regular door. - Fix being able to enter/exit regions with the flag denied by using entity mounting functions in other plugins.
7.0.4 Release 10.09.2024

WorldGuard 7.0.4 (superceded)

Підтримувані версії Minecraft
1.16
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.4 (superceded) - Add support for MC 1.16. Dropped support for previous versions. - Add respawn-anchors flag mirroring the sleep flag (e.g. to prevent using respawn anchors to cause explosions in the overworld) - Add nether vines to vine-growth flag. - Add config option to disable the bypass permission cache. - Fix water-flow flags not checking waterlogged blocks. - Add config option to consider non-player causes (e.g. pistons, flowing water) to only be members of the highest priority region. This should be enabled for plots-within-city-like setups to prevent things in plots from modifying the city. - Fix items dropping from falling blocks that were suppressed by other plugins. - Add config option to block turtle egg trampling. - Fix ride flag being checked on striders that didn't have saddles. - Add config option to have /rg bypass toggled off on login. - Developer changes: Methods taking names in Domains are now explicitly deprecated (was previously just a javadoc comment.); These will eventually be removed: there is no reason to use names over UUIDs. Offline players and NPCs alike have stable UUIDs. - Also for developers; The new com.sk89q.worldguard.protection.util.WorldEditRegionConverter class has some useful static methods to convert to and from WorldEdit's Region and WorldGuard's ProtectedRegion classes. - See the [7.0.3 changelog](https://modrinth.com/project/DKY9btbd) for more details, as many changes have happened since 7.0.2.
7.0.3 Release 10.09.2024

WorldGuard 7.0.3 (MC 1.14.4 - 1.15.2)

Підтримувані версії Minecraft
1.14 1.15
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.3 (MC 1.14.4 - 1.15.2) **This version is compatible with:** - CraftBukkit/Spigot for 1.14.4 or 1.15.2 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.14 - This is the last release supporting MC 1.14 and 1.15. - Decouple chest-access flag from interact flag. IMPORTANT: If you relied on allowing players to access chests via setting the interact flag to allow, you will now need to set the chest-access flag to allow instead (or as well). This does not affect any setups where users were *not* supposed to be able to access chests and other inventories. - Add natural-health-regen and natural-hunger-drain flags. Unlike the heal/feed flags, these can not restore or deplete health/hunger. - Fix the interact flag allowing breaking of turtle eggs (now tied directly to block-trampling flag). - Fix a memory leak that could occur with many many explosives. - Add regions.titles-always-use-default-times config option. Set this to true if you use greeting/farewell titles and another plugin makes the titles disappear too quickly. - Add protection for cauldrons water level changing. - Improve diagnostic hints and information, such as spawn protection warnings, flag colors in region info, etc. - Fix waterlogged blocks bypassing water-flow flag. - Workaround for a CraftBukkit change that made no-physics-sand/gravel non-functional. - Workaround for CraftBukkit throttling move events. - Track projectiles shot by dispensers. - Allowed setting passthrough allow on global to unprotect it if members/owners are added. - Add support for newer forge clients (FML2) in host keys. - Allow using WorldEdit's `//world <worldname>` command to select a world for region commands. This removes the need to use `-w <worldname>` in every command when running commands from console. - Add a teleport-message flag, shown when using `/rg tp`. - Add coral-fade flag, which prevents corals from drying when out of water. - Fix spammy deny-message when walking over redstone ore with certain flag setups. - Improve handling of interacting with various tools in hand that didn't modify blocks. (eg opening a chest with an axe in hand) - Fix allow-all-interact option not being read from per-world configs. - Fix misattribution of pets (eg wolves) in PvP. - Improve performance of hopper checks when on recent builds of Paper. - Add event-handling.break-hoppers-on-denied-move config option to prevent hoppers from being broken (but items still won't be moved). - Note to developers using the WorldGuard API: If you specifically relied on flags such as greeting/farewell, deny-message, etc being StringFlags, be warned that this will change in a future version to support JSON text components. Please plan accordingly.
7.0.2 Release 10.09.2024

WorldGuard 7.0.2 (superceded)

Підтримувані версії Minecraft
1.14 1.15
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.2 (superceded) **This version is compatible with:** - CraftBukkit/Spigot for 1.14.4 or 1.15.2 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.14 **Changes** - Update to MC 1.15. Still compatible with 1.14, and incompatible with 1.13, as before. - Add an informational message when defining a region that overlaps vanilla spawn protection. - Protect against pushing a piston with another piston on a region border. - Protect against buckets in dispensers on region borders.
7.0.1 Release 10.09.2024

WorldGuard 7.0.1 (superceded)

Підтримувані версії Minecraft
1.14
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.1 (superceded) **This version is compatible with:** - CraftBukkit/Spigot for 1.14.4 ([Paper ](https://papermc.io/)recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.14 **Changes** - **If you want to allow players to see lectern books, but not take them, set the interact flag to allow, and the chest-access flag to deny. (or chest-access -g nonmembers deny, to allow members to take books still)** - Add `/rg toggle-bypass` command which temporarily turns off region bypassing until used again. - More improvements to `/rg flag` and `/rg flags` commands. - Fix some checks for adding owners to unclaimed regions. - Fix an issue with time-/weather-lock flags when logging in to a region with the flag set. - Fix cause tracking in vehicles (incl. breaking lilypads in a boat) - Use async teleports on Paper. - Include hopper minecarts in the ignore hoppers config setting. - Add sugar cane and cacti to the crop-growth flag. Bamboo is also included pending Spigot throwing an event for it. - Specifically track when players ignite creepers with flint and steel. - Fix fuzziness when using bonemeal near a protected region. - Fix color codes not applying in greeting, etc flags when placed after a newline (\n). - Add applicable region information to `/wg report`. - Fix pistons flag not applying to sticky pistons pulling blocks. - Add some custom metrics for bStats. - Everything in the RC/beta changelog below. 7.0.1 release candidate/beta changes - Add ravager-grief flag. - Fix overprotection of unsaddled pigs with the ride flag. - Fix lava fire defaulting to off (won't change existing configs). - Fix damaged/chipped anvils not respecting use flag like regular anvils. - Add on-equip blacklist event. Note that it is overprotective due to deficiencies in Bukkit API. - Update WorldEdit CUI when using /rg select. - Add config option to disable villagers getting zapped into witches. ("weather.disable-villager-witchification") - Add entity support to interact-whitelist config option (use the Material of the corresponding item). - Fix vehicle-place protecting the rails at the very top of region boundaries incorrectly. - Fix for emptying buckets on waterloggable blocks. - Whitelist all player -> player interactions (previously was spammy in pvp). - Fix sleep flag not protecting against explosions in nether/end. - Add config for the teleport-on-void to reset fall distance. - Fix config options taking material lists requiring "minecraft:" namespace. - Fix disallowed-lightning-blocks situationally not working. - Fix errors that occurred when plugins used falling block entities with non-item materials. - Add special support for Paper servers (papermc.io): Paper's API allows us to track who launched fireworks. - Fireworks are now protected by default. On Paper servers, members can use them by default (to deal damage), on non-Paper servers, flag firework-damage allow to revert to old behavior (everyone can deal damage with fireworks by default). - Misc performance enhancements for Paper servers. - Add 'regions.use-paper-entity-origin' as an experimental setting (default off) for Paper servers. Enabling it will make non-player entities be treated as members of the place they spawned, instead of their current location when flags are checked.
7.0.0 Release 10.09.2024

WorldGuard 7.0.0 (for MC 1.13.2)

Підтримувані версії Minecraft
1.13
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 7.0.0 (for MC 1.13.2) **This version is compatible with:** - CraftBukkit/Spigot for 1.13.2 / 1.14.2 (Paper recommended) - THIS VERSION IS NOT COMPATIBLE WITH VERSIONS PRIOR TO 1.13 **Changes** - Added support for MC 1.13, dropped support for previous versions. - Added lots of interactive text in e.g. /rg info command. - Added /rg flags command which allows viewing and interactively setting all flags on a region. - Large behind-the-scenes changes to WorldGuard's API (developers, see [https://worldguard.enginehub.org/en/latest/developer/](https://worldguard.enginehub.org/en/latest/developer/)) - Places that used numeric block ids (e.g. blacklist) should now use Minecraft's new string IDs. - Fix various interactions with NPCs and region protection. - Sponge-simulation now destroys kelp and seagrass, and de-waterlogs blocks. - Added an option to block conduit effects. - Fix using newlines in string flags such as greeting and farewell. - Add item-frame-rotation flag. - Ender chests no longer require chest-access (since they don't have inventories). - Add kelp to vine-growth flag/config. - Add block-trampling flag (for turtle eggs and farmland). - Add snowman-trails flag. - Track potion area-of-effect cloud causes for pvp etc. protection. - Add confirmation to /stoplag command. - Forcefully eject players from vehicles trying to force their way into entry deny regions (and out of exit deny). - Fix removing child regions when removing a region with children. - Fix some over-protectiveness of pistons. - Chat and command flags (send-/receive- and allowed-/blocked-) now respect deny-message flag. - Misc fixes.
6.2.2 Release 10.09.2024

WorldGuard 6.2.2 (for MC 1.12.2)

Підтримувані версії Minecraft
1.12
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 6.2.2 (for MC 1.12.2) This is the last release before MC 1.13 versions.
6.2.1 Release 10.09.2024

WorldGuard 6.2.1 (superceded)

Підтримувані версії Minecraft
1.12
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 6.2.1 (superceded) If you are upgrading from a version earlier than 1.11 (1.10 or below), please read the following: - Due to changes in Spigot libraries, if you used the LWC plugin, you will likely get an "UnsatisfiedLinkException" error when starting your server. This will prevent WorldGuard from working properly. It is highly recommended you update to the unofficial LWC build and remove your LWC "lib" folder. If you get anything error related to "org.sqlite.core.NativeDB", try: making /tmp/ executable, switching to oraclejdk, and/or running with "-Dsqlite.purejava=true". These are not WorldGuard issues and we cannot fix them for you. - If you used a third-party plugin that added custom flags to WorldGuard, it may stop working with 6.2. It is highly recommended you backup your region files. Although WorldGuard will attempt to preserve the flags, they will likely be non-functional. Now that WorldGuard natively supports a custom flags API, third-party plugins will have to update to the new API before they work again. ** ** **This version supports only Minecraft 1.12.** It may partially function as far back as 1.8, but it is recommended to use version 6.2 for Minecraft versions 1.11.2 and below as you will encounter errors when running commands. **NEW DOCUMENTATION:** There is [new documentation](http://docs.enginehub.org/manual/worldguard/latest/). Developers: There is a page on using the new custom flag API. ## Changes in 6.2.1 - Flower pots are more strictly protected (via build, not just interact). - Added a config options (mobs.block-armor-stand-destroy) that does exactly what it says. - Added a firework-damage flag that does exactly what it says. - Add a wither-damage flag (protects from the explosion of the wither itself, not the skull projectiles) - Fix errors spamming console if invalid chest (3 or more connected chests) were connected to a hopper. - Improved readability of flag list when invalid flag is entered. ## Changes in 6.2 - Added 1.11 blocks. - Add config option to prevent teleport and spawn flags from being set outside of their region. - Added custom flags API. - Added custom session handler API. - Add transient property to regions for API. - Changed potion-splash flag to include throwing lingering potions. - Removed the construct flag. It has been deprecated for a very long time. - Fixed ender crystal protection. - Fixed some backwards compatibility issues. - Fixed mobs not igniting in regions due to Spigot changes. ## Changes in 6.1.2 - Added support for new blocks in 1.8, 1.9, and 1.10. - Added protection from nether portals being created in protected region (enable via config `nether-portal-protection`). - Added protection from slime block piston contraptions pushing into or pulling from regions. - Added `chorus-fruit-teleport` flag, works similar to `enderpearl` to prevent teleportation. - Added protection from pulling armor stands, items, and entities from protected regions. - Changed order of greeting and farewell flags on adjacent regions. When leaving a region with a farewell flag and entering one with a greeting flag, the farewell message will be shown first now. - Changed /heal command to also fill food/saturation meters. - Changed fall damage prevention to also prevent flying into walls with elytra being fatal. - Fixed fire-spread flag only preventing destruction, now prevents spreading too as per its name. - Fixed creepers targeting players being able to blow things up in certain cases. - Fixed armor stands being removed by /stoplag. - Fixed some issues with fireballs being able to explode when ghast-fireball was set to deny. - Fixed a lot of other minor issues. ## Changes in 6.1 - Added `exit-via-teleport` flag (default allow) to control exiting an exit=deny region via teleportation. - Added a `fall-damage` flag to control player damage caused by falling. - Added a `time-lock` flag to lock players' time of day. Valid values are from 0 to 24000 for absolute time, or +- any number for relative time. - Added a `weather-lock` flag to lock players' weather. Valid values are "clear" or "downfall". Unset to restore to normal world weather. - Added `-s` to the event debugging commands to show a stack trace rather than attempt to detect the causing plugin. - Added support for using the `-e` argument (sets an empty value for the flag) in the flag set command when the type of flag is of the 'set' type. - Added NPCs from the Citizens plugin to a whitelist so they are not protected. - Added support for Spigot's BlockExplodeEvent. - Changed tripwire to fall under the `use` flag. - Changed enderchests to fall under the `use` flag. - Changed vehicles and animals so they are not included in the `interact` flag. - Changed the display of custom blacklist messages to no longer include a period at the end. - Changed protection logic to consider connected chests. - Changed the heal and feed flags to increase values for players who are invincible (or in creative mode) but not decrease them. - Changed PvP protection to consider both attacker and defender locations. - Fixed missing protection data for some 1.8-added blocks. - Fixed compatibility issues with MC 1.7. - Fixed inverted daylight detectors not being protected. - Fixed spawn eggs not being included in protection. - Fixed piston blocking not working due to a bug in Spigot. - Fixed the blocking of certain invalid entity damage events. - Fixed creeper explosions not being blocked in certain situations with explosion related flags set. - Fixed "stickiness" with some position-related flags, sometimes resulting in rubber banding in the exit flags. - Fixed armor stands so that they are treated more like item frames than mobs. - Fixed blocks (e.g. sugar canes) adjacent to physics blocks (e.g. sand) not updating. - Fixed a NullPointerException that occurred sometimes when generating the scheduler section of the report function (`/wg report`). - Fixed the "no XP drops" configuration not functioning following a previous release. - Fixed changes to region ownership sometimes not triggering a region database save. - Fixed bucket protection displaying the "deny effect" even if bucket use was not prevented. - Fixed CommandFilter matching emoticons and other unwanted characters. - Fixed an exception occurring sometimes during game mode changes. - Fixed primed TNT being checked twice for TNT flags. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 6.1.7 or newer.
6.2 Release 10.09.2024

WorldGuard 6.2 (MC 1.8 - 1.11)

Підтримувані версії Minecraft
1.8 1.9 1.10 1.11
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
# 1.11 UPGRADE NOTE: ## Due to changes in Spigot libraries, if you used the LWC plugin, you will likely get an "UnsatisfiedLinkException" error when starting your server. This will prevent WorldGuard from working properly. It is highly recommended you update to the unofficial LWC build and remove your LWC "lib" folder. # CUSTOM FLAGS USERS: ## If you used a third-party plugin that added custom flags to WorldGuard, it may stop working with 6.2. It is highly recommended you backup your region files. Although WorldGuard will attempt to preserve the flags, they will likely be non-functional. Now that WorldGuard natively supports a custom flags API, third-party plugins will have to update to the new API before they work again. This version supports Minecraft 1.9 through 1.11, and will mostly function as far back as 1.7. **NEW DOCUMENTATION:** There is [new documentation](http://docs.enginehub.org/manual/worldguard/latest/). Developers: There is a page on using the new custom flag API. ## Changes in 6.2 - Added 1.11 blocks. - Add config option to prevent teleport and spawn flags from being set outside of their region. - Added custom flags API. - Added custom session handler API. - Add transient property to regions for API. - Changed potion-splash flag to include throwing lingering potions. - Removed the construct flag. It has been deprecated for a very long time. - Fixed ender crystal protection. - Fixed some backwards compatibility issues. - Fixed mobs not igniting in regions due to Spigot changes. ## Changes in 6.1.2 - Added support for new blocks in 1.8, 1.9, and 1.10. - Added protection from nether portals being created in protected region (enable via config `nether-portal-protection`). - Added protection from slime block piston contraptions pushing into or pulling from regions. - Added `chorus-fruit-teleport` flag, works similar to `enderpearl` to prevent teleportation. - Added protection from pulling armor stands, items, and entities from protected regions. - Changed order of greeting and farewell flags on adjacent regions. When leaving a region with a farewell flag and entering one with a greeting flag, the farewell message will be shown first now. - Changed /heal command to also fill food/saturation meters. - Changed fall damage prevention to also prevent flying into walls with elytra being fatal. - Fixed fire-spread flag only preventing destruction, now prevents spreading too as per its name. - Fixed creepers targeting players being able to blow things up in certain cases. - Fixed armor stands being removed by /stoplag. - Fixed some issues with fireballs being able to explode when ghast-fireball was set to deny. - Fixed a lot of other minor issues. ## Changes in 6.1 - Added `exit-via-teleport` flag (default allow) to control exiting an exit=deny region via teleportation. - Added a `fall-damage` flag to control player damage caused by falling. - Added a `time-lock` flag to lock players' time of day. Valid values are from 0 to 24000 for absolute time, or +- any number for relative time. - Added a `weather-lock` flag to lock players' weather. Valid values are "clear" or "downfall". Unset to restore to normal world weather. - Added `-s` to the event debugging commands to show a stack trace rather than attempt to detect the causing plugin. - Added support for using the `-e` argument (sets an empty value for the flag) in the flag set command when the type of flag is of the 'set' type. - Added NPCs from the Citizens plugin to a whitelist so they are not protected. - Added support for Spigot's BlockExplodeEvent. - Changed tripwire to fall under the `use` flag. - Changed enderchests to fall under the `use` flag. - Changed vehicles and animals so they are not included in the `interact` flag. - Changed the display of custom blacklist messages to no longer include a period at the end. - Changed protection logic to consider connected chests. - Changed the heal and feed flags to increase values for players who are invincible (or in creative mode) but not decrease them. - Changed PvP protection to consider both attacker and defender locations. - Fixed missing protection data for some 1.8-added blocks. - Fixed compatibility issues with MC 1.7. - Fixed inverted daylight detectors not being protected. - Fixed spawn eggs not being included in protection. - Fixed piston blocking not working due to a bug in Spigot. - Fixed the blocking of certain invalid entity damage events. - Fixed creeper explosions not being blocked in certain situations with explosion related flags set. - Fixed "stickiness" with some position-related flags, sometimes resulting in rubber banding in the exit flags. - Fixed armor stands so that they are treated more like item frames than mobs. - Fixed blocks (e.g. sugar canes) adjacent to physics blocks (e.g. sand) not updating. - Fixed a NullPointerException that occurred sometimes when generating the scheduler section of the report function (`/wg report`). - Fixed the "no XP drops" configuration not functioning following a previous release. - Fixed changes to region ownership sometimes not triggering a region database save. - Fixed bucket protection displaying the "deny effect" even if bucket use was not prevented. - Fixed CommandFilter matching emoticons and other unwanted characters. - Fixed an exception occurring sometimes during game mode changes. - Fixed primed TNT being checked twice for TNT flags. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 6.1 or newer.
6.1.2 Release 10.09.2024

WorldGuard 6.1.2 (superceded)

Підтримувані версії Minecraft
1.9 1.10
Завантажувачі / Платформи
bukkit paper spigot
Показати зміни
## WorldGuard 6.1.2 (superceded) This version supports Minecraft 1.9 through 1.10, and should be backwards compatible with 1.8 and 1.7. **NEW DOCUMENTATION:** There is [new documentation](http://docs.enginehub.org/manual/worldguard/latest/). ## Changes in 6.1.2 - Added support for new blocks in 1.8, 1.9, and 1.10. - Added protection from nether portals being created in protected region (enable via config `nether-portal-protection`). - Added protection from slime block piston contraptions pushing into or pulling from regions. - Added `chorus-fruit-teleport` flag, works similar to `enderpearl` to prevent teleportation. - Added protection from pulling armor stands, items, and entities from protected regions. - Changed order of greeting and farewell flags on adjacent regions. When leaving a region with a farewell flag and entering one with a greeting flag, the farewell message will be shown first now. - Changed /heal command to also fill food/saturation meters. - Changed fall damage prevention to also prevent flying into walls with elytra being fatal. - Fixed fire-spread flag only preventing destruction, now prevents spreading too as per its name. - Fixed creepers targeting players being able to blow things up in certain cases. - Fixed armor stands being removed by /stoplag. - Fixed some issues with fireballs being able to explode when ghast-fireball was set to deny. - Fixed a lot of other minor issues. ## Changes in 6.1 - Added `exit-via-teleport` flag (default allow) to control exiting an exit=deny region via teleportation. - Added a `fall-damage` flag to control player damage caused by falling. - Added a `time-lock` flag to lock players' time of day. Valid values are from 0 to 24000 for absolute time, or +- any number for relative time. - Added a `weather-lock` flag to lock players' weather. Valid values are "clear" or "downfall". Unset to restore to normal world weather. - Added `-s` to the event debugging commands to show a stack trace rather than attempt to detect the causing plugin. - Added support for using the `-e` argument (sets an empty value for the flag) in the flag set command when the type of flag is of the 'set' type. - Added NPCs from the Citizens plugin to a whitelist so they are not protected. - Added support for Spigot's BlockExplodeEvent. - Changed tripwire to fall under the `use` flag. - Changed enderchests to fall under the `use` flag. - Changed vehicles and animals so they are not included in the `interact` flag. - Changed the display of custom blacklist messages to no longer include a period at the end. - Changed protection logic to consider connected chests. - Changed the heal and feed flags to increase values for players who are invincible (or in creative mode) but not decrease them. - Changed PvP protection to consider both attacker and defender locations. - Fixed missing protection data for some 1.8-added blocks. - Fixed compatibility issues with MC 1.7. - Fixed inverted daylight detectors not being protected. - Fixed spawn eggs not being included in protection. - Fixed piston blocking not working due to a bug in Spigot. - Fixed the blocking of certain invalid entity damage events. - Fixed creeper explosions not being blocked in certain situations with explosion related flags set. - Fixed "stickiness" with some position-related flags, sometimes resulting in rubber banding in the exit flags. - Fixed armor stands so that they are treated more like item frames than mobs. - Fixed blocks (e.g. sugar canes) adjacent to physics blocks (e.g. sand) not updating. - Fixed a NullPointerException that occurred sometimes when generating the scheduler section of the report function (`/wg report`). - Fixed the "no XP drops" configuration not functioning following a previous release. - Fixed changes to region ownership sometimes not triggering a region database save. - Fixed bucket protection displaying the "deny effect" even if bucket use was not prevented. - Fixed CommandFilter matching emoticons and other unwanted characters. - Fixed an exception occurring sometimes during game mode changes. - Fixed primed TNT being checked twice for TNT flags. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 6.1 or newer.
6.1 Release 10.09.2024

WorldGuard 6.1

Підтримувані версії Minecraft
1.7.2 1.7.9 1.8.1
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 6.1 This version supports Minecraft 1.7.9, 1.7.10 and 1.8. **NEW DOCUMENTATION:** There is [new documentation](http://docs.enginehub.org/manual/worldguard/latest/). ## Changes in 6.1 - Added `exit-via-teleport` flag (default allow) to control exiting an exit=deny region via teleportation. - Added a `fall-damage` flag to control player damage caused by falling. - Added a `time-lock` flag to lock players' time of day. Valid values are from 0 to 24000 for absolute time, or +- any number for relative time. - Added a `weather-lock` flag to lock players' weather. Valid values are "clear" or "downfall". Unset to restore to normal world weather. - Added `-s` to the event debugging commands to show a stack trace rather than attempt to detect the causing plugin. - Added support for using the `-e` argument (sets an empty value for the flag) in the flag set command when the type of flag is of the 'set' type. - Added NPCs from the Citizens plugin to a whitelist so they are not protected. - Added support for Spigot's BlockExplodeEvent. - Changed tripwire to fall under the `use` flag. - Changed enderchests to fall under the `use` flag. - Changed vehicles and animals so they are not included in the `interact` flag. - Changed the display of custom blacklist messages to no longer include a period at the end. - Changed protection logic to consider connected chests. - Changed the heal and feed flags to increase values for players who are invincible (or in creative mode) but not decrease them. - Changed PvP protection to consider both attacker and defender locations. - Fixed missing protection data for some 1.8-added blocks. - Fixed compatibility issues with MC 1.7. - Fixed inverted daylight detectors not being protected. - Fixed spawn eggs not being included in protection. - Fixed piston blocking not working due to a bug in Spigot. - Fixed the blocking of certain invalid entity damage events. - Fixed creeper explosions not being blocked in certain situations with explosion related flags set. - Fixed "stickiness" with some position-related flags, sometimes resulting in rubber banding in the exit flags. - Fixed armor stands so that they are treated more like item frames than mobs. - Fixed blocks (e.g. sugar canes) adjacent to physics blocks (e.g. sand) not updating. - Fixed a NullPointerException that occurred sometimes when generating the scheduler section of the report function (`/wg report`). - Fixed the "no XP drops" configuration not functioning following a previous release. - Fixed changes to region ownership sometimes not triggering a region database save. - Fixed bucket protection displaying the "deny effect" even if bucket use was not prevented. - Fixed CommandFilter matching emoticons and other unwanted characters. - Fixed an exception occurring sometimes during game mode changes. - Fixed primed TNT being checked twice for TNT flags. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.6 or newer.
5.9 Release 10.09.2024

WorldGuard 5.9

Підтримувані версії Minecraft
1.6.4 1.7.2 1.7.4
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.9 **Changes in v5.9:** - Added a config option to allow explosion flags to only prevent block damage - Added allow-tamed-spawns setting, on by default. This will stop WorldGuard from culling tamed animals. - Added config option and flag to prevent soil from drying naturally. - Added formatting codes, &k/l/m/n/o and &x (reset). - Added snow-fall-blocks option to config to restrict snow fall to certain blocks - Allow players to add newlines (\n) via command, not just manually in yml. - Allow the console to load/save all region managers with one command. - Changed entity report format slightly. - Check bypass perms for item-drop flag. - Check for entities and projectiles removing items from frames too. - Fix being able to use bonemeal to turn tall grass into double plants. - Fix number of arguments for migratedb command. - Fixed addowner/addmember commands adding command artifacts. Specifically, "-w <world>" will no longer be added when using it. - Fixed milking cows in protected areas due to changes in Bukkit. - Fixed ProtectedCuboidRegion::getPoints() returning points in wrong order. - Fixed snowman trails being treated as snow fall. - Make /rg list default to own regions if the player doesn't have permission otherwise. - Protected items in item frames in protected regions. - Resolved an issue where explosions of type OTHER_EXPLOSION were ignoring the world configuration settings. - Send item-use blacklist event when right-clicking entities. - Transformed the BlockFadeEvent handler into a switch. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.6 or newer.
5.8 Release 10.09.2024

WorldGuard 5.8

Підтримувані версії Minecraft
1.6.1 1.6.2
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.8 **Changes in v5.8:** **Highlight: Support for MC 1.6.1 and 1.6.2** - BREAKING CHANGE: This version has been built for versions of Bukkit for MC 1.6.1 and newer. Do not try to use this version of WG on an older Bukkit version. - Added support for Minecraft 1.6+. Actual support of new 1.6 additions is dependant on Bukkit. Please use a newer build of Bukkit if, for example, you seem to be unable to add "Horses" to your lists of entities. - Added mobs.disable-snowman-trails to disable the trails left by walking snowmen. - Added -a flag to /region removeowner and /region removemember to remove all objects. - Teleporting is now handled by entry/exit flags. If this is causing people to get entirely stuck inside entry/exit deny regions, set the new setting 'use-player-teleports' to 'false' in your configuration. - Updated formatting for region commands, especially /region info. - Changed permissions checking for /region commands to be more consistent, checking for region IDs as a sub-node. This means that if some permissions for some region commands no longer work, add '.*' to the end of permission lines for WG in your permission plugin. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.7 or newer.
5.7.5 Release 10.09.2024

WorldGuard 5.7.5

Підтримувані версії Minecraft
1.5 1.5.1 1.5.2
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7.5 **Changes in v5.7.5:** - Small patch for some issues in 5.7.4, such as firecharge usage and allowed-cmd flag being broken. - NB: Due to the way firecharges and lighters are handled in Bukkit, you will have to set the `__global__` lighter flag to ALLOW to let people use them outside regions by default. Type `/rg f __global__ lighter allow`. Note that in future versions this will no longer be required as a workaround is in place. **Changes in v5.7.4:** - BREAKING CHANGE: Removed the cyan "`**`" in front of greeting and farewell messages to allow more customizability. You can re-add them by adding "&c`**` " to the flag. - Fixed an issue enderpearling inside exit/entry deny regions. - Added checks to players teleporting in and out of exit/entry regions. - Fix bad matching in blocked and allowed command flags. - Fixed heal flag bugs when player max health was increased. - Add fishing to xp blocker. - Applied other-explosion flag to entity damage as well. - Fixed an issue with interaction that should allow blacklisting item use actions with no block involved (eg fishing rods, potions) - Fix witherskull/fireball settings not being differentiated in one case - Allow cow milking in no-build areas - Fix infinite durability breaking items instantly. **Changes in v5.7.3:** - Fixed the error caused by Bukkit's change of the TNT minecart API. **Changes in v5.7.2:** - Updated to MineCraft 1.5. - Added TNT Minecart support. They are handled with the same flags/settings as TNT. - Added mining and smelting xp handling to the xp drops flag and setting. - Fixed a few edge cases for placing items on region borders. - Legacy: Fixed issue with `//stack` not respecting item metadata. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.6 or newer.
5.7.4 Release 10.09.2024

WorldGuard 5.7.4

Підтримувані версії Minecraft
1.5 1.5.1 1.5.2
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7.4 **Changes in v5.7.4:** - BREAKING CHANGE: Removed the cyan "`**`" in front of greeting and farewell messages to allow more customizability. You can re-add them by adding "&c`**` " to the flag. - Fixed an issue enderpearling inside exit/entry deny regions. - Added checks to players teleporting in and out of exit/entry regions. - Fix bad matching in blocked and allowed command flags. - Fixed heal flag bugs when player max health was increased. - Add fishing to xp blocker. - Applied other-explosion flag to entity damage as well. - Fixed an issue with interaction that should allow blacklisting item use actions with no block involved (eg fishing rods, potions) - Fix witherskull/fireball settings not being differentiated in one case - Allow cow milking in no-build areas - Fix infinite durability breaking items instantly. **Changes in v5.7.3:** - Fixed the error caused by Bukkit's change of the TNT minecart API. **Changes in v5.7.2:** - Updated to MineCraft 1.5. - Added TNT Minecart support. They are handled with the same flags/settings as TNT. - Added mining and smelting xp handling to the xp drops flag and setting. - Fixed a few edge cases for placing items on region borders. - Legacy: Fixed issue with `//stack` not respecting item metadata. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.6 or newer.
5.7.3 Release 10.09.2024

WorldGuard 5.7.3

Підтримувані версії Minecraft
1.5
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7.3 **Changes in v5.7.3:** - Fixed the error caused by Bukkit's change of the TNT minecart API. **Changes in v5.7.2:** - Updated to MineCraft 1.5. - Added TNT Minecart support. They are handled with the same flags/settings as TNT. - Added mining and smelting xp handling to the xp drops flag and setting. - Fixed a few edge cases for placing items on region borders. - Legacy: Fixed issue with `//stack` not respecting item metadata. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.3 or newer.
5.7.2 Release 10.09.2024

WorldGuard 5.7.2

Підтримувані версії Minecraft
1.5
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7.2 **Changes in 5.7.2:** - Updated to MineCraft 1.5. - Added TNT Minecart support. They are handled with the same flags/settings as TNT. - Added mining and smelting xp handling to the xp drops flag and setting. - Fixed a few edge cases for placing items on region borders. - Legacy: Fixed issue with `//stack` not respecting item metadata. - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.2.
5.7.1 Release 10.09.2024

WorldGuard 5.7.1

Підтримувані версії Minecraft
1.4.6 1.4.7
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7.1 **Have you updated?** You should update **[WorldEdit](https://modrinth.com/project/1u6JkXh5) to 5.5.1 or newer** and **CraftBukkit to 1.4.6-R0.1 or newer**. ** Changes in this version:** - Added a vine growth config option and flag. - Added support for many commands to be used from console. Usage is with -w flag and a world name e.g. `/rg addmem <id> <player> -w <worldname>` `/rg flag <id> <flag> -w <worldname> <flagvalue>` - Fixed bug that blocks placing plants in flower pots. - Fixed permissions check for /rg tp - Fixed enderchests not being accessible (they are now part of the USE flag) - Fixed an issue with slabs being placable in protected regions. This was also fixed in CraftBukkit but has been left in for users running other versions. - Fixed wither skulls being handled with other fireballs, despite having their own settings. - Fixed item frames being placable on region borders. - Fixed a bug that made explosions more ineffective than they should have been. - Fixed bonemeal usage in protected regions. - Fixed special minecarts being placable in protected regions. - Fixed bugs being placable on region borders. - Fixed wolves bypassing pvp flags. ** Changes in 5.7:** - Fixed thread sync issue with FlagStateManager. - Fixed dragon egg region protection not working in certain cases. - Added beacon and anvil usage protection in regions. - Add mobs.block-enderdragon-portal-creation to stop enderdragons from making portals on death. - Fix TNT being lethal in some case when damage was disabled. - Fix snowballs and enderpearls being able to knock players back in pvp deny regions. - Add subcommand support for allowed and blocked command flags. - Add max-players-allowed and max-players-reject-message flags to limit the numbers of players in a region. - Fix players being able to plant cocoa beans in protected areas. - Add an enderpearl flag to prevent players from teleporting to and from regions. - Added mobs.block-other-explosions config setting and other-explosion flag to block explosions caused by uncovered things, such as other plugins. (It doesn't actually have to be a mob) - Fix mob damage setting and flag not blocking the DoT wither effect. - Ghast fireball flag will not block blaze fireballs from lighting things on fire. - Fixed players without region permissions being able to trigger tripwires, use enderchests, use wooden buttons, and put plants in flower pots. - Added mobs.block-zombie-door-destruction setting to stop zombies from breaking down doors while difficulty is set to hard. **Changes in 5.6.5:** - Added mobs.block-above-ground-slimes to block slimes spawning naturally above ground. - Added security.deop-everyone-on-join to de-op all players when they join. - Added security.block-in-game-op-command to prevent usage of /op from in-game. - Fixed a NullPointerException in PlayerInteract involving water potions and potion blocking. - Fixed an issue with snowballs being blocked in regions. - Fixed a regression that appeared in 5.6.2 that caused paintings and item frames to no longer be properly protected. - Changed dragon eggs to be checked like it is a broken block in regions. - Moved developer's WGBukkit class to package com.sk89q.worldguard.bukkit. **Changes in 5.6.3:** - Added helper WGBukkit class to get references to WorldGuard from other plugins. - Added physics.vine-like-rope-ladders to make ladders work like vines. As long as the top ladder block is present, ladder blocks will hold even if they have no block behind them, like a rope ladder. - Fixed NullPointerException in PlayerInteractEvent caused by potion blocking. - Fixed mobs.block-{item-frame,painting}-destroy not working. ** Changes from 5.6.1 and 5.6.2:** - Added a mycelium-spread region flag. - Added a dynamics.disable-mycelium-spread configuration setting. - Added new gameplay.block-potions option. For example:gameplay: block-potions: [invisibility, speed] - Fixed a bug in the entity explosion event handler that caused a NullPointerException. **Changes from 5.6:** - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5.1 or newer. - CraftBukkit should be updated to version 1.4.6-R0.1 or newer. - For other issues, [see our issue tracker for bugs affecting this version](https://github.com/EngineHub/WorldGuard/issues) (updated automatically).
5.7 Release 10.09.2024

WorldGuard 5.7

Підтримувані версії Minecraft
1.4.6
Завантажувачі / Платформи
bukkit spigot
Показати зміни
## WorldGuard 5.7 **Have you updated?** You should update **[WorldEdit](https://modrinth.com/project/1u6JkXh5) to 5.5 or newer** and **CraftBukkit to 1.4.6-R0.1 or newer**. ** Changes in this version:** - Fixed thread sync issue with FlagStateManager. - Fixed dragon egg region protection not working in certain cases. - Added beacon and anvil usage protection in regions. - Add mobs.block-enderdragon-portal-creation to stop enderdragons from making portals on death. - Fix TNT being lethal in some case when damage was disabled. - Fix snowballs and enderpearls being able to knock players back in pvp deny regions. - Add subcommand support for allowed and blocked command flags. - Fix players being able to plant cocoa beans in protected areas. - Add an enderpearl flag to prevent players from teleporting to and from regions. - Added mobs.block-other-explosions config setting and other-explosion flag to block explosions caused by uncovered things, such as other plugins. (It doesn't actually have to be a mob) - Fix mob damage setting and flag not blocking the DoT wither effect. - Ghast fireball flag will not block blaze fireballs from lighting things on fire. - Fixed players without region permissions being able to trigger tripwires, use enderchests, use wooden buttons, and put plants in flower pots. - Added mobs.block-zombie-door-destruction setting to stop zombies from breaking down doors while difficulty is set to hard. **Changes in 5.6.5:** - Added mobs.block-above-ground-slimes to block slimes spawning naturally above ground. - Added security.deop-everyone-on-join to de-op all players when they join. - Added security.block-in-game-op-command to prevent usage of /op from in-game. - Fixed a NullPointerException in PlayerInteract involving water potions and potion blocking. - Fixed an issue with snowballs being blocked in regions. - Fixed a regression that appeared in 5.6.2 that caused paintings and item frames to no longer be properly protected. - Changed dragon eggs to be checked like it is a broken block in regions. - Moved developer's WGBukkit class to package com.sk89q.worldguard.bukkit. **Changes in 5.6.3:** - Added helper WGBukkit class to get references to WorldGuard from other plugins. - Added physics.vine-like-rope-ladders to make ladders work like vines. As long as the top ladder block is present, ladder blocks will hold even if they have no block behind them, like a rope ladder. - Fixed NullPointerException in PlayerInteractEvent caused by potion blocking. - Fixed mobs.block-{item-frame,painting}-destroy not working. ** Changes from 5.6.1 and 5.6.2:** - Added a mycelium-spread region flag. - Added a dynamics.disable-mycelium-spread configuration setting. - Added new gameplay.block-potions option. For example:gameplay: block-potions: [invisibility, speed] - Fixed a bug in the entity explosion event handler that caused a NullPointerException. **Changes from 5.6:** - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.5 or newer. - CraftBukkit should be updated to version 1.4.6-R0.1 or newer. - For other issues, [see our issue tracker for bugs affecting this version](https://github.com/EngineHub/WorldGuard/issues) (updated automatically).
5.6.5 Release 10.09.2024

WorldGuard 5.6.5

Підтримувані версії Minecraft
1.2.5 1.3.2 1.4.2
Завантажувачі / Платформи
bukkit
Показати зміни
## WorldGuard 5.6.5 **Have you updated?** You should update **[WorldEdit](https://modrinth.com/project/1u6JkXh5) to 5.4.5 or newer** and (if you're running MC 1.4) **CraftBukkit to 1.4.2-R0.2 or newer**. ** Changes in this version:** - Added mobs.block-above-ground-slimes to block slimes spawning naturally above ground. - Added security.deop-everyone-on-join to de-op all players when they join. - Added security.block-in-game-op-command to prevent usage of /op from in-game. - Fixed a NullPointerException in PlayerInteract involving water potions and potion blocking. - Fixed an issue with snowballs being blocked in regions. - Fixed a regression that appeared in 5.6.2 that caused paintings and item frames to no longer be properly protected. - Changed dragon eggs to be checked like it is a broken block in regions. - Moved developer's WGBukkit class to package com.sk89q.worldguard.bukkit. **Changes in 5.6.3:** - Added helper WGBukkit class to get references to WorldGuard from other plugins. - Added physics.vine-like-rope-ladders to make ladders work like vines. As long as the top ladder block is present, ladder blocks will hold even if they have no block behind them, like a rope ladder. - Fixed NullPointerException in PlayerInteractEvent caused by potion blocking. - Fixed mobs.block-{item-frame,painting}-destroy not working. ** Changes from 5.6.1 and 5.6.2:** - Added a mycelium-spread region flag. - Added a dynamics.disable-mycelium-spread configuration setting. - Added new gameplay.block-potions option. For example:gameplay: block-potions: [invisibility, speed] - Fixed a bug in the entity explosion event handler that caused a NullPointerException. **Changes from 5.6:** - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). - [WorldEdit](https://modrinth.com/project/1u6JkXh5) should be updated to version 5.4.5 or newer. - CraftBukkit should be updated to version 1.4.2-R0.2 or newer (for MC 1.4 users only). - If you want to block Withers spawning, use "WITHERBOSS" and not "WITHER". - For other issues, [see our issue tracker for bugs affecting this version](https://github.com/EngineHub/WorldGuard/issues) (updated automatically).
5.6.3 Release 10.09.2024

WorldGuard 5.6.3

Підтримувані версії Minecraft
1.2.5 1.3.2 1.4.2
Завантажувачі / Платформи
bukkit
Показати зміни
## WorldGuard 5.6.3 - Added helper WGBukkit class to get references to WorldGuard from other plugins. - Added physics.vine-like-rope-ladders to make ladders work like vines. As long as the top ladder block is present, ladder blocks will hold even if they have no block behind them, like a rope ladder. - Fixed NullPointerException in PlayerInteractEvent caused by potion blocking. - Fixed mobs.block-{item-frame,painting}-destroy not working. Thank you to def for testing the above fixes and features. ** Changes from 5.6.1 and 5.6.2:** - Added a mycelium-spread region flag. - Added a dynamics.disable-mycelium-spread configuration setting. - Added new gameplay.block-potions option. For example:gameplay: block-potions: [invisibility, speed] - Fixed a bug in the entity explosion event handler that caused a NullPointerException. **Changes from 5.6:** - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). - **CRITICAL:** You should update WorldEdit to at least version 5.4.5. - **CRITICAL:** If you are using MC 1.4.2, you should update CraftBukkit to version 1.4.2-R0.2 or newer if you desire to block the new 1.4 features. - If you want to block Withers spawning, use "WITHERBOSS" and not "WITHER". - Known issues (updated live): [https://github.com/EngineHub/WorldGuard/issues)
5.6.2 Release 10.09.2024

WorldGuard 5.6.2

Підтримувані версії Minecraft
1.2.5 1.3.2 1.4.2
Завантажувачі / Платформи
bukkit
Показати зміни
## WorldGuard 5.6.2 5.6.1 didn't block splash potions very well, so 5.6.1 was released. The following are the changes between 5.6 and 5.6.2. - Added a mycelium-spread region flag. - Added a dynamics.disable-mycelium-spread configuration setting. - Added new gameplay.block-potions option. For example:gameplay: block-potions: [invisibility, speed] - Fixed a bug in the entity explosion event handler that caused a NullPointerException. Thank you for gabizou for his contribution in this release. Did you update from a version older than 5.6? Here's what was new in 5.6: - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). **Warning:** You should update WorldEdit to the latest version. **Warning:** If you are using MC 1.4.2, you should update CraftBukkit to the latest version. If you want to block Withers spawning, use "WITHERBOSS" and not "WITHER". Known issues: [https://github.com/EngineHub/WorldGuard/issues)
5.6 Release 10.09.2024

WorldGuard 5.6

Підтримувані версії Minecraft
1.2.5 1.3.2 1.4.2
Завантажувачі / Платформи
bukkit
Показати зміни
## WorldGuard 5.6 - Added official support for Minecraft 1.4. Support for 1.3.2 (and below) is still provided in this release. - Added support for new and existing explosion types. - Added support for blocking withers with the following settings: mobs: block-wither-explosions: false block-wither-block-damage: false block-wither-skull-explosions: false block-wither-skull-block-damage: true - Added support for blocking item frames (and their use) in protected regions. - Added item frame destruction region flags (if you wish to disable item frame destruction completely). - (Re-)added support for priority R-tree region indexes. This means quicker region lookup, and better support for servers with thousands of regions. - Improved /region info output for -g group flags. - Allowed removing of -g group flags with /region flag. - Allowed /region flag to set group and value at once. - Deleting a region flag now also deletes group flag. - Fixed detection of attack by projectiles to be more accurate. - Fixed support for saving non-string flags in the MySQL region support. - Fixed spurious comma in "Flags:" /region info output. - Fixed players who are not in god mode not receiving damage in PVP areas from enderpearls. - Players will now be told that they are in a no-PvP area if they are in one and attempting to attack someone, or that the player they are attacking is in a no-PvP area, if that is the case instead. - Fixed an issue where region.getId() was lowercase'd each pass of a for loop in MySQLDatabase.updatePoly2dPoints(). - Fixed mob damage from projectiles not being properly blocked in regions whereapplicable. - Changed default region wand to leather (#334). **Warning:** You should update WorldEdit to the latest version. If you want to block Withers spawning, use "WITHERBOSS" and not "WITHER"
5.5.2 Release 10.09.2024

WorldGuard 5.5.2

Підтримувані версії Minecraft
1.2.4 1.2.5
Завантажувачі / Платформи
bukkit
Показати зміни
## WorldGuard 5.5.2 Thanks to narthollis for his contributions in this version. - Added potion-splash flag to block splash potions - Add entity-painting-destroy which can be used to prevent entities from destroying paintings (skeletons firing arrows) - Added send-chat and receive-chat flags - Fixed having regions in multiple worlds with the same name not working with MySQL - A cancellable event is now fired if WorldGuard disallows PvP. (for developers!) - Made /region setparent check worldguard.region.setparent.own/member.<parent> instead of worldguard.region.setparent.own/member.<child>. - Allowed passing #<index> in place of a region ID, where <index> is the index as displayed by /region list. - Fixed an error that occured when clearing a non-existant region's parent. - Added a -s flag to /region teleport, which sends you to the spawn point instead of the teleport point of a region. - Added region/role-based permissions to /region teleport. - BREAKING CHANGE: Added a LocationFlag class and made the teleport and spawn flags use it. - /region info -s now selects the region being queried. - Added /region teleport <id>. - Vector flags can now be set to the current location with the value "here" and to a specific position with x,y,z. - Made /region info show the region you're in if you don't specify an id explicitly. - Prevent block ignition from lightning strikes if lightning is blocked in region. Fixes #1175 - Correctly check both WEPIF and superperms in WorldGurdPlugin.broadcastNotification() - Destroy fire blocks when fire-spread is disallowed - Added a construct flag that can be used to restrict block placing/destroying in zones to certain roles. - Added FallingSand to list of intensive entities to be removed with /halt-activiy. - Replaced all usage of CreatureType by EntityType. - Updated to support Bukkit 1.2-R0.3 and newer - Made auto-god-mode disabled by default again. - Added sign protection check disable. - Cleaned up javadoc, deprecated duplicate methods, other cleanup - Added a RegionGroupFlag to evey region flag Using the /region flag command with -g, the region group that the region flag applies to can be set. **Warning:** You need to update WorldEdit to version 5.1 or newer.